#!/bin/bash -e
set -o pipefail

function kapply() {
    for f in "$@"; do
        kubectl apply -f \
            <(envsubst "$(env | xargs printf '$%s ')" < "manifests/$f")
    done
}

function kcreatesec() {
    kubectl create secret generic --save-config --dry-run=client -oyaml "$@" | kubectl apply -f-
}

function kcreatecm() {
    kubectl create configmap --dry-run=client -oyaml "$@" | kubectl apply -f-
}

function kgseckey() {
    local sec="$1"; shift
    local key="$1"; shift

    kubectl get secret "$sec" -o jsonpath="{.data.$key}" | base64 -d
}

function kgcmkey() {
    local cm="$1"; shift
    local key="$1"; shift

    kubectl get configmap "$cm" -o jsonpath="{.data.$key}"
}

kcreatecm homepage \
    --from-file=bookmarks.yaml=<(envsubst "$(env | xargs printf '$%s ')" < config/bookmarks.yaml) \
    --from-file=custom.css=<(envsubst "$(env | xargs printf '$%s ')" < config/custom.css) \
    --from-file=custom.js=<(envsubst "$(env | xargs printf '$%s ')" < config/custom.js) \
    --from-file=kubernetes.yaml=<(envsubst "$(env | xargs printf '$%s ')" < config/kubernetes.yaml) \
    --from-file=settings.yaml=<(envsubst "$(env | xargs printf '$%s ')" < config/settings.yaml) \
    --from-file=widgets.yaml=<(envsubst "$(env | xargs printf '$%s ')" < config/widgets.yaml)

kapply common/clusterrole.yaml common/app.yaml

kubectl rollout restart deployment app
